@@ -11,6 +11,8 @@
 #' If set to \code{NULL} the second criterion wont be applied.
 #' @param sg_crit3 If set to \code{TRUE} the third criterion will be applied automatically adjusting the critical value for missingness.
 #' If set to \code{FALSE} the third criterion wont be applied.
+#' @param sg_crit3_alpha Numeric, alpha for the student t-test (two-tailed) to determine the critical value to be used for the third criterion.
+#' Degrees of freedom are based on the number of available data in the three sessions preceding the gain and the three sessions following the gain.
 #' @param id_var_name String, specifying the name of the ID variable. Each row should have a unique value.
 #' @param sg_var_list Vector, specifying the variable names of each measurement point sequentially.
 #' @param tx_start_var_name String, specifying the variable name of the first measurement point of the intervention.
@@ -40,7 +42,7 @@
 #'                 sg_measure_name = "bdi",
 #'                 multiple_sg_select = "largest")
 
-create_byperson <- function(data, sg_crit1_cutoff, id_var_name, sg_var_list, tx_start_var_name, tx_end_var_name, sg_measure_name, multiple_sg_select = c("first", "last", "smalles", "largest"), data_is_bysg = FALSE, identify = c("sg", "sl"), sg_crit2_pct = .25, sg_crit3 = TRUE, identify_sg_1to2 = FALSE) {
+create_byperson <- function(data, sg_crit1_cutoff, id_var_name, sg_var_list, tx_start_var_name, tx_end_var_name, sg_measure_name, multiple_sg_select = c("first", "last", "smalles", "largest"), data_is_bysg = FALSE, identify = c("sg", "sl"), sg_crit2_pct = .25, sg_crit3 = TRUE, sg_crit3_alpha = .05, identify_sg_1to2 = FALSE) {
 
   # Check arguments
   multiple_sg_select <- base::match.arg(multiple_sg_select)
@@ -58,6 +60,7 @@ create_byperson <- function(data, sg_crit1_cutoff, id_var_name, sg_var_list, tx_
                              sg_crit1_cutoff = sg_crit1_cutoff,
                              sg_crit2_pct = sg_crit2_pct,
                              sg_crit3 = sg_crit3,
+                             sg_crit3_alpha = sg_crit3_alpha,
                              tx_start_var_name = tx_start_var_name,
                              tx_end_var_name = tx_end_var_name,
                              sg_measure_name = sg_measure_name,
